@@ -8,9 +8,7 @@ module PuppetSyntax
 
       output = []
 
-      if Puppet::Test::TestHelper.respond_to?(:initialize) # 3.1+
-        Puppet::Test::TestHelper.initialize
-      end
+      Puppet::Test::TestHelper.initialize
       Puppet::Test::TestHelper.before_all_tests
       called_before_all_tests = true
 
@@ -43,9 +41,9 @@ module PuppetSyntax
         e =~ /^You cannot collect( exported resources)? without storeconfigs being set/
       }
 
-      # tag parameter in class raise warnings notice in output that prevent from succeed
+      # tag and schedule parameters in class raise warnings notice in output that prevent from succeed
       output.reject! { |e|
-        e =~ /^tag is a metaparam; this value will inherit to all contained resources in the /
+        e =~ /^(tag|schedule) is a metaparam; this value will inherit to all contained resources in the /
       }
 
       deprecations = output.select { |e|
@@ -62,8 +60,6 @@ module PuppetSyntax
 
     private
     def validate_manifest(file)
-      Puppet[:parser] = 'future' if PuppetSyntax.future_parser and Puppet.version.to_i < 4
-      Puppet[:app_management] = true if PuppetSyntax.app_management && (Puppet::Util::Package.versioncmp(Puppet.version, '4.3.0') >= 0 && Puppet.version.to_i < 5)
       Puppet[:tasks] = true if Puppet::Util::Package.versioncmp(Puppet.version, '5.4.0') >= 0 and file.match(/.*plans\/.*\.pp$/)
       Puppet::Face[:parser, :current].validate(file)
     end
