@@ -5,17 +5,19 @@ require 'rake/tasklib'
 module PuppetSyntax
   class RakeTask < ::Rake::TaskLib
     def filelist(paths)
+      excludes = PuppetSyntax.exclude_paths
+      excludes.push('pkg/**/*')
       files = FileList[paths]
       files.reject! { |f| File.directory?(f) }
-      files.exclude(*PuppetSyntax.exclude_paths)
+      files.exclude(*excludes)
     end
 
     def filelist_manifests
-      filelist("**/*.pp")
+      filelist(PuppetSyntax.manifests_paths)
     end
 
     def filelist_templates
-      filelist(["**/templates/**/*.erb", "**/templates/**/*.epp"])
+      filelist(PuppetSyntax.templates_paths)
     end
 
     def filelist_hiera_yaml
@@ -25,42 +27,14 @@ module PuppetSyntax
     def initialize(*args)
       desc 'Syntax check Puppet manifests and templates'
       task :syntax => [
-        'syntax:check_puppetlabs_spec_helper',
         'syntax:manifests',
         'syntax:templates',
         'syntax:hiera',
       ]
 
       namespace :syntax do
-        task :check_puppetlabs_spec_helper do
-          psh_present = task(:syntax).actions.any? { |a|
-            a.inspect.match(/puppetlabs_spec_helper\/rake_tasks\.rb:\d+/)
-          }
-
-          if psh_present
-            $stderr.puts <<-EOS
-[WARNING] A conflicting :syntax rake task has been defined by
-puppetlabs_spec_helper/rake_tasks. You should either disable this or upgrade
-to puppetlabs_spec_helper >= 0.8.0 which now uses puppet-syntax.
-            EOS
-          end
-        end
-
         desc 'Syntax check Puppet manifests'
         task :manifests do |t|
-          if Puppet.version.to_i >= 4 and PuppetSyntax.future_parser
-            $stderr.puts <<-EOS
-[INFO] Puppet 4 has been detected and `future_parser` has been set to
-'true'. The `future_parser setting will be ignored.
-            EOS
-          end
-          if Puppet::Util::Package.versioncmp(Puppet.version, '4.3.0') < 0 and PuppetSyntax.app_management
-            $stderr.puts <<-EOS
-[WARNING] Puppet `app_management` has been detected but the Puppet
-version is less then 4.3.  The `app_management` setting will be ignored.
-            EOS
-          end
-
           $stderr.puts "---> #{t.name}"
 
           c = PuppetSyntax::Manifests.new
@@ -74,9 +48,16 @@ version is less then 4.3.  The `app_management` setting will be ignored.
           $stderr.puts "---> #{t.name}"
 
           c = PuppetSyntax::Templates.new
-          errors = c.check(filelist_templates)
-          $stdout.puts "#{errors.join("\n")}\n" unless errors.empty?
-          exit 1 unless errors.empty?
+          result = c.check(filelist_templates)
+          unless result[:warnings].empty?
+            $stdout.puts "WARNINGS:"
+            $stdout.puts result[:warnings].join("\n")
+          end
+          unless result[:errors].empty?
+            $stderr.puts "ERRORS:"
+            $stderr.puts result[:errors].join("\n")
+            exit 1
+          end
         end
 
         desc 'Syntax check Hiera config files'
